/*
 *  Copyright (C) Chaperon. All rights reserved.
 *  -------------------------------------------------------------------------
 *  This software is published under the terms of the Apache Software License
 *  version 1.1, a copy of which has been included  with this distribution in
 *  the LICENSE file.
 */

package net.sourceforge.chaperon.grammar.production;

import java.io.InvalidObjectException;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.ObjectStreamException;
import java.io.Serializable;
import java.util.Enumeration;
import java.util.Hashtable;

/**
 * This class represent a reduce type for productions
 *
 * @version $Revision: 1.1 $ $Date: 2002/04/09 21:46:17 $
 */
public class ReduceType implements Serializable
{

	/**
	 * The neglect type
	 */
	public static final int NEGLECT_TYPE = 0;

	/**
	 * The instance of the neglect type
	 */
	public static final ReduceType NEGLECT = new ReduceType(NEGLECT_TYPE,
																						 "neglect");

	/**
	 * The resolve type
	 */
	public static final int RESOLVE_TYPE = 1;

	/**
	 * The instance of the resolve type
	 */
	public static final ReduceType RESOLVE = new ReduceType(RESOLVE_TYPE,
																						 "resolve");

	/**
	 * The append type
	 */
	public static final int APPEND_TYPE = 2;

	/**
	 * The instance of the append type
	 */
	public static final ReduceType APPEND = new ReduceType(APPEND_TYPE,
																						"append");

	/**
	 * The normal type
	 */
	public static final int NORMAL_TYPE = 3;

	/**
	 * The instance of the normal type
	 */
	public static final ReduceType NORMAL = new ReduceType(NORMAL_TYPE,
																						"normal");

	private static Hashtable _memberTable = init();

	private int _type = -1;

	private String _stringValue = null;

	/**
	 * The private constructor for the reduce type
	 *
	 * @param type Integer type      
	 * @param value String type
	 */
	private ReduceType(int type, String value)
	{
		super();
		_type = type;
		_stringValue = value;
	}

	/**
	 * Returns an enumeration of all possible instances of ReduceTyp
	 */
	public static Enumeration enumerate()
	{
		return _memberTable.elements();
	}

	/**
	 * Returns the type of this ReduceType
	 */
	public int getType()
	{
		return _type;
	}

	/**
	**/
	private static java.util.Hashtable init()
	{
		Hashtable members = new Hashtable();

		members.put("neglect", NEGLECT);
		members.put("resolve", RESOLVE);
		members.put("append", APPEND);
		members.put("normal", NORMAL);
		return members;
	}

	/**
	 * Returns the String representation of this ReduceType
	 */
	public String toString()
	{
		return _stringValue;
	}

	/**
	 * Returns a new ReduceType based on the given String value.
	 * @param string
	 */
	public static ReduceType valueOf(String string)
	{
		Object obj = null;

		if (string != null)
			obj = _memberTable.get(string);
		if (obj == null)
		{
			String err = "'" + string + "' is not a valid ReduceType";

			throw new IllegalArgumentException(err);
		}
		return (ReduceType) obj;
	}

  private void writeObject(ObjectOutputStream out) throws IOException
  {
    out.defaultWriteObject();
    out.writeInt(_type);
    out.writeUTF(_stringValue);
  }

  private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
  {
    in.defaultReadObject();
    _type = in.readInt();
    _stringValue = in.readUTF();
  }

  /** 
   * Deals with the issue of uniqueness when we are dealing with more
   * than one VM by adding the read symbol to the hash table, if it
   * isn't already there.
   */
  public Object readResolve() throws ObjectStreamException
  {
    if (!_memberTable.containsKey(_stringValue))
      throw new InvalidObjectException("'" + _stringValue + "' is not a valid ReduceType");
    return (ReduceType) (_memberTable.get(_stringValue));
  }
}
